
# q-expansion of newform 3584.2.b.h, downloaded from the LMFDB on 01 May 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 3584
weight = 2
poly_data = [36, 72, -66, -80, 158, -48, 3, -12, 12, -4, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-2273868, -1109304, 6984030, -2064154, 12764, -313772, 463067, -140969, 39443, 1883], 1451844], [[-9846, -3911724, -1103322, 3566650, -877304, -201334, -289322, 209765, -84722, 15829], 725922], [[-1858968, 2932884, 582306, -2799902, 934966, -18106, 125815, -198991, 66337, -19133], 725922], [[4740426, -3111984, -850908, 2918896, -620576, -159244, -199391, 257948, -88931, 22726], 725922], [[-1480806, 5074416, 1214952, -4770464, 1332430, 124556, 285913, -353158, 124663, -31664], 725922], [[9111492, 3643452, -24722286, 18554846, -4281784, 1741774, -2393731, 1411729, -432283, 77231], 1451844], [[165024, 19098, -416874, 604930, -207770, 33773, -55454, 48281, -15476, 3820], 40329], [[-2399184, 129366, 5808030, -11128874, 4084954, -413401, 850897, -878263, 287347, -76448], 725922], [[-15620868, -5172948, 40233750, -41125610, 11110924, -2816962, 4281475, -3098881, 975355, -209987], 1451844]]

hecke_ring_character_values = [[1023, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1541, [-1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [1025, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 1, 0, 0, 0], [1, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 1, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 1], [2, 0, 0, 1, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, -1, 1, 0, -1], [1, 0, 1, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, -2, 0, 1, -1], [0, 0, 0, -1, 1, 1, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 1, 1, -1], [-2, 0, 1, 0, 1, 0, 0, 0, 0, 0], [0, 2, 0, 0, 0, 0, 2, 1, -1, 0], [2, 0, -1, 0, 1, 0, 0, 0, 0, 0], [0, 3, 0, 0, 0, 0, 2, -1, -1, 1], [0, 1, 0, 0, 0, 0, 1, 1, 0, 1], [0, 0, 0, 0, 0, 0, 1, -2, 0, 0], [0, -2, 0, 0, 0, 0, 0, 1, 1, 0], [0, 0, 0, 0, -1, 1, 0, 0, 0, 0], [-4, 0, 1, 1, -1, 0, 0, 0, 0, 0], [-4, 0, 0, 0, 1, -1, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 2, 0, 0], [-2, 0, 0, 0, 1, 1, 0, 0, 0, 0], [4, 0, 1, 0, 0, -3, 0, 0, 0, 0], [0, -2, 0, 0, 0, 0, 0, 2, 2, 1], [-4, 0, -1, -2, 1, 2, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 2, 1, -2], [0, -3, 0, 0, 0, 0, 2, 1, 1, 1], [3, 0, 1, 3, -1, -1, 0, 0, 0, 0], [-3, 0, -1, 0, 0, -2, 0, 0, 0, 0], [0, 3, 0, 0, 0, 0, 4, 2, -2, 0], [-4, 0, -1, -1, 1, 2, 0, 0, 0, 0], [0, -3, 0, 0, 0, 0, -3, 1, 0, 1], [0, -1, 0, 0, 0, 0, 0, -2, 1, -1], [1, 0, -1, 0, -2, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 4, -2, 0, 3], [0, 2, 0, 0, 0, 0, 2, 0, 1, 0], [-6, 0, -1, 2, -1, -2, 0, 0, 0, 0], [0, -4, 0, 0, 0, 0, 0, -2, 0, -1], [0, 2, 0, 0, 0, 0, 0, 1, -1, 0], [0, -2, 0, 0, 0, 0, -1, -4, -2, 2], [-8, 0, -2, 0, 0, 2, 0, 0, 0, 0], [9, 0, 0, 0, -2, 1, 0, 0, 0, 0], [0, -5, 0, 0, 0, 0, 0, 3, -1, -1], [4, 0, 2, -1, 1, -1, 0, 0, 0, 0], [0, 4, 0, 0, 0, 0, -2, -3, 1, 0], [6, 0, -1, 1, 2, 1, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, -5, -1, 2, -1], [0, 4, 0, 0, 0, 0, 0, 0, 0, 1], [-2, 0, 1, -1, -1, -2, 0, 0, 0, 0], [13, 0, -1, 2, 2, 0, 0, 0, 0, 0], [8, 0, 0, 1, 2, 0, 0, 0, 0, 0], [0, -5, 0, 0, 0, 0, 0, 2, 0, 0], [-2, 0, -1, 1, 2, -1, 0, 0, 0, 0], [8, 0, -2, -2, 1, 1, 0, 0, 0, 0], [0, 4, 0, 0, 0, 0, 0, 2, 0, 1], [2, 0, 1, -1, -2, -1, 0, 0, 0, 0], [0, 3, 0, 0, 0, 0, -4, 0, 1, -1], [0, 0, 2, 2, 0, 2, 0, 0, 0, 0], [0, -3, 0, 0, 0, 0, 0, 0, -4, 0], [0, 2, 0, 0, 0, 0, 4, 2, 2, -1], [0, 1, 0, 0, 0, 0, 4, -4, 0, 0], [8, 0, -3, 1, 0, -1, 0, 0, 0, 0], [-6, 0, 1, -4, -1, -2, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, -2, 1, 3, 1], [0, -6, 0, 0, 0, 0, -6, -1, 1, 0], [3, 0, 1, 3, 1, -3, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -4, 3, 1, 0], [0, -2, 0, 0, 0, 0, -1, -4, 2, -2], [-8, 0, -3, 1, 0, 1, 0, 0, 0, 0], [3, 0, 1, 4, -2, 0, 0, 0, 0, 0], [6, 0, 2, 0, -2, -2, 0, 0, 0, 0], [0, 9, 0, 0, 0, 0, 0, 0, -1, 1], [0, 2, 0, 0, 0, 0, 8, -3, -1, 2], [10, 0, -2, -3, 1, 1, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 2, 7, 3, -1], [0, -2, 0, 0, 0, 0, -3, -2, -2, 2], [-1, 0, 2, 0, -2, -3, 0, 0, 0, 0], [-8, 0, 2, -1, 1, -3, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 2, -2, 0], [0, 3, 0, 0, 0, 0, -4, 0, 1, -1], [-7, 0, -1, -2, -2, 0, 0, 0, 0, 0], [-2, 0, -3, 0, 0, -1, 0, 0, 0, 0], [-14, 0, -2, -2, -2, 2, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 1, -1, 2], [-10, 0, -1, -3, -3, 2, 0, 0, 0, 0], [3, 0, 1, 3, -3, 1, 0, 0, 0, 0], [0, 2, 0, 0, 0, 0, -1, -4, -2, -2], [-4, 0, 4, 0, -2, -2, 0, 0, 0, 0], [0, -3, 0, 0, 0, 0, 5, -1, 2, 1], [0, 0, -1, 0, -1, -4, 0, 0, 0, 0], [11, 0, 1, -2, 0, 2, 0, 0, 0, 0], [0, -2, 0, 0, 0, 0, 2, -3, -1, 2], [0, 0, 0, 0, 0, 0, 6, -2, -1, 0], [18, 0, 2, 0, -2, 2, 0, 0, 0, 0], [0, 6, 0, 0, 0, 0, 3, -6, -2, 2], [8, 0, 1, 4, -1, -4, 0, 0, 0, 0], [0, 7, 0, 0, 0, 0, 3, -3, 0, -1], [0, -5, 0, 0, 0, 0, -2, 6, -3, -3], [0, -4, 0, 0, 0, 0, 6, -2, -3, -2], [0, -5, 0, 0, 0, 0, -4, 5, -1, -5], [0, 1, 0, 0, 0, 0, -3, 11, 2, -3], [1, 0, 1, 1, -1, -7, 0, 0, 0, 0], [0, -2, 0, 0, 0, 0, 0, -5, -3, -2], [4, 0, -3, -5, 4, 1, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 3, -5, 0, -1], [-18, 0, -3, 1, 0, 3, 0, 0, 0, 0], [-8, 0, -4, -4, 0, 4, 0, 0, 0, 0], [-14, 0, 0, 0, 3, -5, 0, 0, 0, 0], [28, 0, 3, 1, -2, -5, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 4, 0, 3, 3], [13, 0, 0, -4, 2, 1, 0, 0, 0, 0], [0, 7, 0, 0, 0, 0, 0, -2, 2, 0], [12, 0, 0, -2, -2, 2, 0, 0, 0, 0], [1, 0, 0, 2, 2, 1, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, -9, 1, 4, -5], [12, 0, 2, 1, -1, -3, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 4, -2, 3, -1], [0, -8, 0, 0, 0, 0, 2, -8, -1, 6], [0, -6, 0, 0, 0, 0, -4, 4, 2, -1], [4, 0, 0, -6, 0, 4, 0, 0, 0, 0], [0, 14, 0, 0, 0, 0, 1, -6, -2, 2], [0, -8, 0, 0, 0, 0, -2, -4, -1, 4], [0, 7, 0, 0, 0, 0, -4, -4, -4, 0], [0, -3, 0, 0, 0, 0, 2, 2, 3, 5], [0, 3, 0, 0, 0, 0, -4, 5, -1, 5], [10, 0, 6, 3, -5, -5, 0, 0, 0, 0], [-10, 0, -3, 2, 3, 4, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 3, -8, -4, 4], [0, 10, 0, 0, 0, 0, 6, -2, -3, 4], [-15, 0, 3, 0, -2, 4, 0, 0, 0, 0], [17, 0, 1, 4, -2, -2, 0, 0, 0, 0], [0, 3, 0, 0, 0, 0, 12, -4, -3, 5], [14, 0, -4, 3, 1, 1, 0, 0, 0, 0], [4, 0, 2, 1, 4, 4, 0, 0, 0, 0], [0, -12, 0, 0, 0, 0, -5, 2, 4, -4], [0, -9, 0, 0, 0, 0, -5, 3, 2, -5], [0, 0, 0, 0, 0, 0, 4, 2, -4, -1], [5, 0, 1, -1, -3, -1, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, -8, 0, 0], [0, -7, 0, 0, 0, 0, -2, 2, 3, 3], [20, 0, 0, -2, 1, -1, 0, 0, 0, 0], [0, 4, 0, 0, 0, 0, -2, -2, -3, 4], [0, 0, 0, 0, 0, 0, -1, 6, -4, 0], [0, 0, 0, 3, -1, -5, 0, 0, 0, 0], [0, 4, 0, 0, 0, 0, 0, 2, -4, -1], [8, 0, -1, -2, -3, 0, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, -4, -4, -6, 4], [0, 0, -2, -4, 4, 6, 0, 0, 0, 0], [0, 3, 0, 0, 0, 0, -2, 9, 3, -1], [-16, 0, 1, 1, -2, -5, 0, 0, 0, 0], [0, 6, 0, 0, 0, 0, 4, -8, -1, 0], [6, 0, 5, 4, -3, -2, 0, 0, 0, 0], [0, 14, 0, 0, 0, 0, 10, -11, -1, 6], [1, 0, -3, -2, 4, 0, 0, 0, 0, 0], [-8, 0, 0, -2, 5, -1, 0, 0, 0, 0], [2, 0, -3, 4, -4, -1, 0, 0, 0, 0], [-12, 0, -4, 2, -3, -1, 0, 0, 0, 0], [0, -10, 0, 0, 0, 0, 0, -10, -2, 1], [0, -4, 0, 0, 0, 0, -10, 2, 5, 2], [22, 0, 2, -2, 0, -6, 0, 0, 0, 0], [3, 0, -5, -4, 0, 0, 0, 0, 0, 0], [0, -5, 0, 0, 0, 0, -5, 1, 2, -5], [-2, 0, -3, 1, 1, 4, 0, 0, 0, 0], [-12, 0, 0, -7, 3, -1, 0, 0, 0, 0], [-8, 0, 0, -6, 3, -3, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -5, 2, 4, 0], [11, 0, 4, 0, -2, -5, 0, 0, 0, 0], [0, 8, 0, 0, 0, 0, -4, -8, 0, 1], [0, -6, 0, 0, 0, 0, -6, 3, 5, -2], [0, -2, 0, 0, 0, 0, -7, -2, 2, 2], [8, 0, 0, -4, 5, 3, 0, 0, 0, 0], [12, 0, -4, 0, -4, 0, 0, 0, 0, 0], [-14, 0, -1, -2, 5, 0, 0, 0, 0, 0], [-18, 0, -3, -5, 5, 0, 0, 0, 0, 0], [0, -12, 0, 0, 0, 0, -8, -4, 3, 2], [0, -5, 0, 0, 0, 0, -4, 2, 5, 1], [-4, 0, 3, -5, -2, -1, 0, 0, 0, 0], [0, -2, 0, 0, 0, 0, 8, -4, -6, 3], [-19, 0, -1, -2, 2, 0, 0, 0, 0, 0], [0, 15, 0, 0, 0, 0, -5, 1, 2, 3], [0, -3, 0, 0, 0, 0, 6, -11, -3, -3], [-8, 0, -2, 0, -1, 7, 0, 0, 0, 0], [-7, 0, 5, 2, 0, -4, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -4, 4, 0, 3], [0, 5, 0, 0, 0, 0, -10, 1, 5, -1], [0, 1, 0, 0, 0, 0, -3, -11, 0, -3], [-28, 0, -7, 1, 3, 2, 0, 0, 0, 0], [-12, 0, -3, -6, 1, 8, 0, 0, 0, 0], [-12, 0, 2, 0, 2, 6, 0, 0, 0, 0], [0, -6, 0, 0, 0, 0, 4, 2, 5, -4], [0, 6, 0, 0, 0, 0, 2, -2, 3, 2], [0, 4, 0, 0, 0, 0, 4, 2, 4, -1], [0, 6, 0, 0, 0, 0, 6, 8, 1, -2], [6, 0, 3, 1, -3, 2, 0, 0, 0, 0], [33, 0, 1, -1, 3, 1, 0, 0, 0, 0], [0, -15, 0, 0, 0, 0, 6, 2, -1, 1], [12, 0, 1, 3, -2, 7, 0, 0, 0, 0], [-2, 0, 1, -3, 2, 3, 0, 0, 0, 0], [0, 7, 0, 0, 0, 0, 0, -3, 7, 3], [-12, 0, 7, 4, -1, 0, 0, 0, 0, 0], [0, 4, 0, 0, 0, 0, 1, 0, 8, 0], [4, 0, -3, -3, -4, -3, 0, 0, 0, 0], [0, 5, 0, 0, 0, 0, 5, -5, 2, 1], [0, 2, 0, 0, 0, 0, 8, 4, -2, -1], [4, 0, -1, -4, -3, -6, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, -2, 1, -7, 6], [-1, 0, -2, -2, 0, 3, 0, 0, 0, 0], [0, -7, 0, 0, 0, 0, 8, 0, -4, 0], [17, 0, -2, -4, -2, 7, 0, 0, 0, 0], [0, 8, 0, 0, 0, 0, 3, 0, -4, 4], [3, 0, -1, 2, -2, 10, 0, 0, 0, 0], [0, 11, 0, 0, 0, 0, 0, 2, -2, 4], [14, 0, -2, -4, 0, 8, 0, 0, 0, 0], [-10, 0, 6, 5, -3, -1, 0, 0, 0, 0], [-12, 0, -4, 4, 2, 2, 0, 0, 0, 0], [12, 0, -2, -1, 4, -4, 0, 0, 0, 0], [0, 0, 2, 6, -4, 2, 0, 0, 0, 0], [0, 15, 0, 0, 0, 0, 8, 6, -3, 1], [0, -11, 0, 0, 0, 0, -2, 2, 7, -7], [6, 0, -6, 0, 6, -2, 0, 0, 0, 0], [8, 0, 4, 0, 0, -8, 0, 0, 0, 0], [-23, 0, 3, 2, 2, 0, 0, 0, 0, 0], [0, -11, 0, 0, 0, 0, -15, 3, 2, 1], [0, -9, 0, 0, 0, 0, -8, -4, 9, 1], [-2, 0, -3, -1, 1, 4, 0, 0, 0, 0], [7, 0, 1, -2, -2, 12, 0, 0, 0, 0], [-2, 0, -3, 9, -2, 3, 0, 0, 0, 0], [0, -2, 0, 0, 0, 0, 6, 8, 1, 4], [0, -3, 0, 0, 0, 0, -6, 4, 3, 1], [0, -1, 0, 0, 0, 0, 0, 10, 6, 0], [-16, 0, -8, -4, 6, 6, 0, 0, 0, 0], [-12, 0, 4, 4, -2, -2, 0, 0, 0, 0], [0, -3, 0, 0, 0, 0, -8, 6, -2, 0], [-14, 0, -5, -7, 2, 9, 0, 0, 0, 0], [14, 0, -3, -2, 2, -7, 0, 0, 0, 0], [0, 11, 0, 0, 0, 0, 6, 4, 1, -3], [0, 2, 0, 0, 0, 0, 8, 5, 1, 4], [-24, 0, -2, -6, 4, -2, 0, 0, 0, 0], [0, -12, 0, 0, 0, 0, 2, 7, -7, -2], [0, 1, 0, 0, 0, 0, 13, -7, -6, 5], [-34, 0, -1, -1, -6, -3, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 0, 5, -3, 1], [0, 0, -2, 0, 2, 2, 0, 0, 0, 0], [-12, 0, 3, 2, -5, 4, 0, 0, 0, 0], [0, 0, 5, 3, -6, 1, 0, 0, 0, 0], [0, -5, 0, 0, 0, 0, 4, -10, -2, 8], [0, -2, 0, 0, 0, 0, -2, -4, 1, -4], [-12, 0, 0, 2, -5, -7, 0, 0, 0, 0], [0, -7, 0, 0, 0, 0, 4, -10, -5, 1], [-20, 0, 2, 4, -2, -6, 0, 0, 0, 0], [12, 0, 2, 4, 2, -4, 0, 0, 0, 0], [-18, 0, 1, -1, -1, 2, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 7, -6, 0, -8], [0, -14, 0, 0, 0, 0, -10, 11, -5, -6], [0, -5, 0, 0, 0, 0, 0, 4, 1, 1], [0, 13, 0, 0, 0, 0, -7, -7, 0, 1], [0, -8, 0, 0, 0, 0, -3, -2, 4, 4], [-16, 0, 0, 1, -3, -5, 0, 0, 0, 0], [-3, 0, 5, 4, -2, -2, 0, 0, 0, 0], [0, -18, 0, 0, 0, 0, -8, 15, 3, -6], [0, 8, 0, 0, 0, 0, 13, -2, -8, 12], [0, 12, 0, 0, 0, 0, -5, -2, -4, 0], [0, 0, 0, -5, 6, 8, 0, 0, 0, 0], [0, 1, 0, 0, 0, 0, 13, -5, -6, 1], [0, -11, 0, 0, 0, 0, -8, -8, 7, -7], [-2, 0, 9, 5, -7, -4, 0, 0, 0, 0], [0, 6, 0, 0, 0, 0, -6, 12, 5, -6], [0, -7, 0, 0, 0, 0, 0, 1, 1, 7], [0, 4, 0, 0, 0, 0, -20, -2, 4, -5], [0, 6, 0, 0, 0, 0, -4, -5, -7, -2], [-2, 0, 0, -4, 3, -1, 0, 0, 0, 0], [15, 0, 3, -2, -4, -8, 0, 0, 0, 0], [18, 0, -3, -3, 4, 3, 0, 0, 0, 0], [8, 0, -2, -2, 2, -8, 0, 0, 0, 0], [0, 4, 0, 0, 0, 0, 6, 0, -3, 2], [0, 17, 0, 0, 0, 0, 10, -7, -3, -1], [-17, 0, -4, -4, -4, 1, 0, 0, 0, 0], [0, 9, 0, 0, 0, 0, 12, 2, -4, 4], [-10, 0, 0, -4, -4, 6, 0, 0, 0, 0], [24, 0, 0, 6, 1, -5, 0, 0, 0, 0], [-10, 0, 0, -3, -3, 3, 0, 0, 0, 0], [0, 6, 0, 0, 0, 0, -4, -6, -2, 3], [0, 17, 0, 0, 0, 0, 4, -8, -2, 0], [3, 0, -1, 6, -4, -8, 0, 0, 0, 0], [8, 0, -2, -2, 4, 10, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, -4, -5, 3, 3], [-10, 0, -6, -7, -1, 11, 0, 0, 0, 0], [0, 0, 3, -7, 0, -5, 0, 0, 0, 0], [0, 9, 0, 0, 0, 0, 8, -17, -3, 5], [0, -9, 0, 0, 0, 0, 4, 10, 2, 0], [9, 0, 6, -6, 6, 3, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 8, -4, -2, -4], [0, 13, 0, 0, 0, 0, 6, 0, -5, 3], [0, 10, 0, 0, 0, 0, -3, 2, 6, 6], [14, 0, 3, 1, 4, 3, 0, 0, 0, 0], [0, 8, 0, 0, 0, 0, -4, 2, 0, 3], [0, 1, 0, 0, 0, 0, -16, -6, 8, -4], [0, 13, 0, 0, 0, 0, 8, 4, -8, 4], [-32, 0, 1, -4, 5, -2, 0, 0, 0, 0], [0, 9, 0, 0, 0, 0, -12, -3, 1, 3], [-20, 0, 2, 6, 2, 4, 0, 0, 0, 0]]
